
package GLite::Data::FiremanCatalog;

use strict;
no strict 'refs';
use SOAP::Lite;
use GLite::HTTPS;
use Data::Dumper;

=head1 NAME

GLite::Data::FiremanCatalog

=head1 DESCRIPTION

GLite::Data::FileCatalog module provides a Perl client
library for the B<FiremanCatalog> interface.

=head1 METHODS

The methods I<die> if there was a SOAP fault.
The fault string and details are added to the I<die> message.

=over 4

=item B<new($URL)>

Creates an FiremanCatalog object, which is initialized with the
approriate SOAP endpoint. If the URL uses https protocol,
then it will do the HTTPS initialization (locating proxy
certificate) as well.

Note: you have to include the VO name in the URL!

    my $srv = GLite::Data::FiremanCatalog->new('https://service.glite.org:8443/example');

=cut


sub new
{
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    $self->{SOAP} = undef;
    bless( $self, $class );

    my $url = shift;

    defined $url or 
      print STDERR "FiremanCatalog endpoint was not defined!\n" and return;

    GLite::HTTPS::setEnv() if $url =~ /^https:/i;

    $self->{SOAP} = new SOAP::Lite (
        uri => 'org.glite.data.catalog',
        proxy => $url,
        on_fault => sub { my($soap, $res) = @_;
            die $soap->transport->status, "\n" unless(ref $res);
            local $Data::Dumper::Pad = "    Details: ";
            die $res->faultcode(),": ",$res->faultstring(),"\n",
                Dumper($res->faultdetail()), "\n";
        }
    );

    
    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.catalog.service.composite'
    
    $self->{SOAP}->serializer()->maptype->{'ArrayOf_soapenc_string'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_FRCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_StringPair'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_Stat'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_SURLEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_FCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_PermissionEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_Attribute'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_RCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_GUIDStat'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    $self->{SOAP}->serializer()->maptype->{'ArrayOf_tns1_StringBoolean'} = "http://glite.org/wsdl/services/org.glite.data.catalog.service.composite";

    # namespace definitions for 'http://glite.org/wsdl/services/org.glite.data.catalog'
    
    $self->{SOAP}->serializer()->maptype->{'CatalogException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'InternalException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'AuthorizationException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'NotExistsException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'InvalidArgumentException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'Stat'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'GUIDStat'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'Perm'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'BasicPermission'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'ACLEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'Permission'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'SURLEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'RCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'LFNStat'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'FRCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'ExistsException'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'StringPair'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'FCEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'PermissionEntry'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'Attribute'} = "http://glite.org/wsdl/services/org.glite.data.catalog";

    $self->{SOAP}->serializer()->maptype->{'StringBoolean'} = "http://glite.org/wsdl/services/org.glite.data.catalog";


    return $self;
}

    
=pod

=item B<remove(string[] lfns)>

=cut

sub remove {
    my ($self) = shift;
    my $result = $self->{SOAP}->remove(
        __serialize__ArrayOf_soapenc_string('lfns', shift)
    )->result();
    return $result;
}

=pod

=item B<create(FRCEntry[] entries)>

=cut

sub create {
    my ($self) = shift;
    my $result = $self->{SOAP}->create(
        __serialize__ArrayOf_tns1_FRCEntry('entries', shift)
    )->result();
    return $result;
}

=pod

=item B<FRCEntry[] listReplicas(string[] lfns, boolean withPermissions)>

=cut

sub listReplicas {
    my ($self) = shift;
    my $result = $self->{SOAP}->listReplicas(
        __serialize__ArrayOf_soapenc_string('lfns', shift), 
        SOAP::Data->new(name => 'withPermissions', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] listLfn(string[] surls)>

=cut

sub listLfn {
    my ($self) = shift;
    my $result = $self->{SOAP}->listLfn(
        __serialize__ArrayOf_soapenc_string('surls', shift)
    )->result();
    return $result;
}

=pod

=item B<Stat[] getStat(string[] lfns)>

=cut

sub getStat {
    my ($self) = shift;
    my $result = $self->{SOAP}->getStat(
        __serialize__ArrayOf_soapenc_string('lfns', shift)
    )->result();
    return $result;
}

=pod

=item B<addReplica(string lfn, SURLEntry[] newSurls)>

=cut

sub addReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->addReplica(
        SOAP::Data->new(name => 'lfn', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_tns1_SURLEntry('newSurls', shift)
    )->result();
    return $result;
}

=pod

=item B<removeReplica(StringPair[] lfnSurls, boolean removeLfnOnLastReplica)>

=cut

sub removeReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeReplica(
        __serialize__ArrayOf_tns1_StringPair('lfnSurls', shift), 
        SOAP::Data->new(name => 'removeLfnOnLastReplica', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<associateDirWithSchema(string directoryLfn, string schemaName)>

=cut

sub associateDirWithSchema {
    my ($self) = shift;
    my $result = $self->{SOAP}->associateDirWithSchema(
        SOAP::Data->new(name => 'directoryLfn', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'schemaName', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<mkdir(string[] directories, boolean createParents, boolean copyPermFromParent)>

=cut

sub mkdir {
    my ($self) = shift;
    my $result = $self->{SOAP}->mkdir(
        __serialize__ArrayOf_soapenc_string('directories', shift), 
        SOAP::Data->new(name => 'createParents', type => 'xsd:boolean', value => shift), 
        SOAP::Data->new(name => 'copyPermFromParent', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<string[] locate(string startDir, string pattern, long limit)>

=cut

sub locate {
    my ($self) = shift;
    my $result = $self->{SOAP}->locate(
        SOAP::Data->new(name => 'startDir', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'pattern', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'limit', type => 'xsd:long', value => shift)
    )->result();
    return $result;
}

=pod

=item B<symlink(StringPair[] symlinks, boolean copyPermFromParent)>

=cut

sub symlink {
    my ($self) = shift;
    my $result = $self->{SOAP}->symlink(
        __serialize__ArrayOf_tns1_StringPair('symlinks', shift), 
        SOAP::Data->new(name => 'copyPermFromParent', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<rmdir(string[] directories)>

=cut

sub rmdir {
    my ($self) = shift;
    my $result = $self->{SOAP}->rmdir(
        __serialize__ArrayOf_soapenc_string('directories', shift)
    )->result();
    return $result;
}

=pod

=item B<createFile(FCEntry[] entries)>

=cut

sub createFile {
    my ($self) = shift;
    my $result = $self->{SOAP}->createFile(
        __serialize__ArrayOf_tns1_FCEntry('entries', shift)
    )->result();
    return $result;
}

=pod

=item B<unlink(string[] lfns)>

=cut

sub unlink {
    my ($self) = shift;
    my $result = $self->{SOAP}->unlink(
        __serialize__ArrayOf_soapenc_string('lfns', shift)
    )->result();
    return $result;
}

=pod

=item B<mv(StringPair[] entries)>

=cut

sub mv {
    my ($self) = shift;
    my $result = $self->{SOAP}->mv(
        __serialize__ArrayOf_tns1_StringPair('entries', shift)
    )->result();
    return $result;
}

=pod

=item B<updateModifyTime(string[] lfns, long time)>

=cut

sub updateModifyTime {
    my ($self) = shift;
    my $result = $self->{SOAP}->updateModifyTime(
        __serialize__ArrayOf_soapenc_string('lfns', shift), 
        SOAP::Data->new(name => 'time', type => 'xsd:long', value => shift)
    )->result();
    return $result;
}

=pod

=item B<updateValidityTime(string[] lfns, long time)>

=cut

sub updateValidityTime {
    my ($self) = shift;
    my $result = $self->{SOAP}->updateValidityTime(
        __serialize__ArrayOf_soapenc_string('lfns', shift), 
        SOAP::Data->new(name => 'time', type => 'xsd:long', value => shift)
    )->result();
    return $result;
}

=pod

=item B<FCEntry[] readDir(string path, string pattern, long limit, long offset, boolean withPermissions)>

=cut

sub readDir {
    my ($self) = shift;
    my $result = $self->{SOAP}->readDir(
        SOAP::Data->new(name => 'path', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'pattern', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'limit', type => 'xsd:long', value => shift), 
        SOAP::Data->new(name => 'offset', type => 'xsd:long', value => shift), 
        SOAP::Data->new(name => 'withPermissions', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] getGuidForLfn(string[] lfns)>

=cut

sub getGuidForLfn {
    my ($self) = shift;
    my $result = $self->{SOAP}->getGuidForLfn(
        __serialize__ArrayOf_soapenc_string('lfns', shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] getLfnForGuid(string[] guids)>

=cut

sub getLfnForGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->getLfnForGuid(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<FCEntry[] getFileCatalogEntry(string[] lfns)>

=cut

sub getFileCatalogEntry {
    my ($self) = shift;
    my $result = $self->{SOAP}->getFileCatalogEntry(
        __serialize__ArrayOf_soapenc_string('lfns', shift)
    )->result();
    return $result;
}

=pod

=item B<checkPermission(string[] items, Perm perm)>

=cut

sub checkPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->checkPermission(
        __serialize__ArrayOf_soapenc_string('items', shift), 
        __serialize__Perm('perm', shift)
    )->result();
    return $result;
}

=pod

=item B<PermissionEntry[] getPermission(string[] items)>

=cut

sub getPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->getPermission(
        __serialize__ArrayOf_soapenc_string('items', shift)
    )->result();
    return $result;
}

=pod

=item B<setPermission(PermissionEntry[] permissions)>

=cut

sub setPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->setPermission(
        __serialize__ArrayOf_tns1_PermissionEntry('permissions', shift)
    )->result();
    return $result;
}

=pod

=item B<string getVersion()>

=cut

sub getVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getVersion(
    )->result();
    return $result;
}

=pod

=item B<string getSchemaVersion()>

=cut

sub getSchemaVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSchemaVersion(
    )->result();
    return $result;
}

=pod

=item B<string getInterfaceVersion()>

=cut

sub getInterfaceVersion {
    my ($self) = shift;
    my $result = $self->{SOAP}->getInterfaceVersion(
    )->result();
    return $result;
}

=pod

=item B<string getServiceMetadata(string key)>

=cut

sub getServiceMetadata {
    my ($self) = shift;
    my $result = $self->{SOAP}->getServiceMetadata(
        SOAP::Data->new(name => 'key', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<Attribute[] getAttributes(string item, string[] attributeNames)>

=cut

sub getAttributes {
    my ($self) = shift;
    my $result = $self->{SOAP}->getAttributes(
        SOAP::Data->new(name => 'item', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('attributeNames', shift)
    )->result();
    return $result;
}

=pod

=item B<string[] query(string query, string type, int limit, int offset)>

=cut

sub query {
    my ($self) = shift;
    my $result = $self->{SOAP}->query(
        SOAP::Data->new(name => 'query', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'type', type => 'xsd:string', value => shift), 
        SOAP::Data->new(name => 'limit', type => 'xsd:int', value => shift), 
        SOAP::Data->new(name => 'offset', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<setAttributes(string item, Attribute[] attributes)>

=cut

sub setAttributes {
    my ($self) = shift;
    my $result = $self->{SOAP}->setAttributes(
        SOAP::Data->new(name => 'item', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_tns1_Attribute('attributes', shift)
    )->result();
    return $result;
}

=pod

=item B<clearAttributes(string item, string[] attributeNames)>

=cut

sub clearAttributes {
    my ($self) = shift;
    my $result = $self->{SOAP}->clearAttributes(
        SOAP::Data->new(name => 'item', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_soapenc_string('attributeNames', shift)
    )->result();
    return $result;
}

=pod

=item B<Attribute[] listAttributes(string item)>

=cut

sub listAttributes {
    my ($self) = shift;
    my $result = $self->{SOAP}->listAttributes(
        SOAP::Data->new(name => 'item', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<updateStatus(string[] guids, int status, int mask)>

=cut

sub updateStatus {
    my ($self) = shift;
    my $result = $self->{SOAP}->updateStatus(
        __serialize__ArrayOf_soapenc_string('guids', shift), 
        SOAP::Data->new(name => 'status', type => 'xsd:int', value => shift), 
        SOAP::Data->new(name => 'mask', type => 'xsd:int', value => shift)
    )->result();
    return $result;
}

=pod

=item B<createGuid(RCEntry[] entries)>

=cut

sub createGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->createGuid(
        __serialize__ArrayOf_tns1_RCEntry('entries', shift)
    )->result();
    return $result;
}

=pod

=item B<addGuidReplica(string guid, SURLEntry[] newSurls)>

=cut

sub addGuidReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->addGuidReplica(
        SOAP::Data->new(name => 'guid', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_tns1_SURLEntry('newSurls', shift)
    )->result();
    return $result;
}

=pod

=item B<updateGuidStat(string[] guids, GUIDStat[] stats)>

=cut

sub updateGuidStat {
    my ($self) = shift;
    my $result = $self->{SOAP}->updateGuidStat(
        __serialize__ArrayOf_soapenc_string('guids', shift), 
        __serialize__ArrayOf_tns1_GUIDStat('stats', shift)
    )->result();
    return $result;
}

=pod

=item B<updateSurlStat(string guid, SURLEntry[] surlStats)>

=cut

sub updateSurlStat {
    my ($self) = shift;
    my $result = $self->{SOAP}->updateSurlStat(
        SOAP::Data->new(name => 'guid', type => 'xsd:string', value => shift), 
        __serialize__ArrayOf_tns1_SURLEntry('surlStats', shift)
    )->result();
    return $result;
}

=pod

=item B<setMasterReplica(StringPair[] guidSurls)>

=cut

sub setMasterReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->setMasterReplica(
        __serialize__ArrayOf_tns1_StringPair('guidSurls', shift)
    )->result();
    return $result;
}

=pod

=item B<removeGuidReplica(StringPair[] guidSurls, boolean removeGuidOnLastReplica)>

=cut

sub removeGuidReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeGuidReplica(
        __serialize__ArrayOf_tns1_StringPair('guidSurls', shift), 
        SOAP::Data->new(name => 'removeGuidOnLastReplica', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<removeGuid(string[] guids)>

=cut

sub removeGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->removeGuid(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<setDefaultPrincipalPermission(string principal, Permission defaultPermission)>

=cut

sub setDefaultPrincipalPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->setDefaultPrincipalPermission(
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift), 
        __serialize__Permission('defaultPermission', shift)
    )->result();
    return $result;
}

=pod

=item B<setDefaultGlobalPermission(Permission defaultPermission)>

=cut

sub setDefaultGlobalPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->setDefaultGlobalPermission(
        __serialize__Permission('defaultPermission', shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] getGuidForSurl(string[] surls)>

=cut

sub getGuidForSurl {
    my ($self) = shift;
    my $result = $self->{SOAP}->getGuidForSurl(
        __serialize__ArrayOf_soapenc_string('surls', shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] getMasterReplica(string[] guids)>

=cut

sub getMasterReplica {
    my ($self) = shift;
    my $result = $self->{SOAP}->getMasterReplica(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<StringPair[] listSurlsByGuid(string[] guids)>

=cut

sub listSurlsByGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->listSurlsByGuid(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<RCEntry[] listReplicasByGuid(string[] guids, boolean withPermissions)>

=cut

sub listReplicasByGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->listReplicasByGuid(
        __serialize__ArrayOf_soapenc_string('guids', shift), 
        SOAP::Data->new(name => 'withPermissions', type => 'xsd:boolean', value => shift)
    )->result();
    return $result;
}

=pod

=item B<StringBoolean[] hasGuid(string[] guids)>

=cut

sub hasGuid {
    my ($self) = shift;
    my $result = $self->{SOAP}->hasGuid(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<GUIDStat[] getGuidStat(string[] guids)>

=cut

sub getGuidStat {
    my ($self) = shift;
    my $result = $self->{SOAP}->getGuidStat(
        __serialize__ArrayOf_soapenc_string('guids', shift)
    )->result();
    return $result;
}

=pod

=item B<SURLEntry[] getSurlStat(string[] surls)>

=cut

sub getSurlStat {
    my ($self) = shift;
    my $result = $self->{SOAP}->getSurlStat(
        __serialize__ArrayOf_soapenc_string('surls', shift)
    )->result();
    return $result;
}

=pod

=item B<Permission getDefaultPrincipalPermission(string principal)>

=cut

sub getDefaultPrincipalPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->getDefaultPrincipalPermission(
        SOAP::Data->new(name => 'principal', type => 'xsd:string', value => shift)
    )->result();
    return $result;
}

=pod

=item B<Permission getDefaultGlobalPermission()>

=cut

sub getDefaultGlobalPermission {
    my ($self) = shift;
    my $result = $self->{SOAP}->getDefaultGlobalPermission(
    )->result();
    return $result;
}


=pod

=back

=head1 TYPES

=over 4

=cut


    
=pod

=item B<ArrayOf_soapenc_string>

    my $myArrayOf_soapenc_string = [ 'string1', 'string2', ...];

=cut

sub __serialize__ArrayOf_soapenc_string {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_soapenc_string';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'xsd:string'},
        value => [ map { SOAP::Data->new(type => 'xsd:string', value => $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_FRCEntry>

    my $myArrayOf_tns1_FRCEntry = [ $myFRCEntry1, $myFRCEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_FRCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_FRCEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'FRCEntry'},
        value => [ map { __serialize__FRCEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_StringPair>

    my $myArrayOf_tns1_StringPair = [ $myStringPair1, $myStringPair2, ... ];

=cut

sub __serialize__ArrayOf_tns1_StringPair {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_StringPair';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'StringPair'},
        value => [ map { __serialize__StringPair(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_Stat>

    my $myArrayOf_tns1_Stat = [ $myStat1, $myStat2, ... ];

=cut

sub __serialize__ArrayOf_tns1_Stat {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_Stat';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'Stat'},
        value => [ map { __serialize__Stat(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_SURLEntry>

    my $myArrayOf_tns1_SURLEntry = [ $mySURLEntry1, $mySURLEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_SURLEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_SURLEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'SURLEntry'},
        value => [ map { __serialize__SURLEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_FCEntry>

    my $myArrayOf_tns1_FCEntry = [ $myFCEntry1, $myFCEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_FCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_FCEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'FCEntry'},
        value => [ map { __serialize__FCEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_PermissionEntry>

    my $myArrayOf_tns1_PermissionEntry = [ $myPermissionEntry1, $myPermissionEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_PermissionEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_PermissionEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'PermissionEntry'},
        value => [ map { __serialize__PermissionEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_Attribute>

    my $myArrayOf_tns1_Attribute = [ $myAttribute1, $myAttribute2, ... ];

=cut

sub __serialize__ArrayOf_tns1_Attribute {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_Attribute';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'Attribute'},
        value => [ map { __serialize__Attribute(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_RCEntry>

    my $myArrayOf_tns1_RCEntry = [ $myRCEntry1, $myRCEntry2, ... ];

=cut

sub __serialize__ArrayOf_tns1_RCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_RCEntry';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'RCEntry'},
        value => [ map { __serialize__RCEntry(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_GUIDStat>

    my $myArrayOf_tns1_GUIDStat = [ $myGUIDStat1, $myGUIDStat2, ... ];

=cut

sub __serialize__ArrayOf_tns1_GUIDStat {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_GUIDStat';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'GUIDStat'},
        value => [ map { __serialize__GUIDStat(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<ArrayOf_tns1_StringBoolean>

    my $myArrayOf_tns1_StringBoolean = [ $myStringBoolean1, $myStringBoolean2, ... ];

=cut

sub __serialize__ArrayOf_tns1_StringBoolean {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl array w/o type info
    my $type     = 'ArrayOf_tns1_StringBoolean';
    my $value    = {};

    return SOAP::Data->new (
        name => $name,
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'StringBoolean'},
        value => [ map { __serialize__StringBoolean(undef, $_); } @{$rawValue} ]
    );
}

=pod

=item B<CatalogException>

    my $myCatalogException = {
        message => 'string'
    };

=cut

sub __serialize__CatalogException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'CatalogException';
    my $value    = shift || {};

    
    $value->{'message'} = SOAP::Data->new (
        name => 'message',
        type => 'xsd:string',
        value => $rawValue->{'message'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<InternalException>

    my $myInternalException = new CatalogException (
        
    );

=cut

sub __serialize__InternalException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InternalException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<AuthorizationException>

    my $myAuthorizationException = new CatalogException (
        
    );

=cut

sub __serialize__AuthorizationException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'AuthorizationException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<NotExistsException>

    my $myNotExistsException = new CatalogException (
        
    );

=cut

sub __serialize__NotExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'NotExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<InvalidArgumentException>

    my $myInvalidArgumentException = new CatalogException (
        
    );

=cut

sub __serialize__InvalidArgumentException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'InvalidArgumentException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<Stat>

    my $myStat = {
        modifyTime => $mylong, 
        creationTime => $mylong, 
        size => $mylong
    };

=cut

sub __serialize__Stat {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Stat';
    my $value    = shift || {};

    
    $value->{'modifyTime'} = SOAP::Data->new (
        name => 'modifyTime',
        type => 'xsd:long',
        value => $rawValue->{'modifyTime'}
    );

    $value->{'creationTime'} = SOAP::Data->new (
        name => 'creationTime',
        type => 'xsd:long',
        value => $rawValue->{'creationTime'}
    );

    $value->{'size'} = SOAP::Data->new (
        name => 'size',
        type => 'xsd:long',
        value => $rawValue->{'size'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<GUIDStat>

    my $myGUIDStat = new Stat (
        
    );

=cut

sub __serialize__GUIDStat {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'GUIDStat';
    my $value    = shift || {};

    
    $value->{'status'} = SOAP::Data->new (
        name => 'status',
        type => 'xsd:int',
        value => $rawValue->{'status'}
    );

    $value->{'checksum'} = SOAP::Data->new (
        name => 'checksum',
        type => 'xsd:string',
        value => $rawValue->{'checksum'}
    );


    # calling the superclass' serializer for the rest
    return __serialize__Stat ($name, $rawValue, $type, $value);
}

=pod

=item B<Perm>

    my $myPerm = {
        permission => $myboolean, 
        remove => $myboolean, 
        read => $myboolean, 
        write => $myboolean, 
        list => $myboolean, 
        execute => $myboolean, 
        getMetadata => $myboolean, 
        setMetadata => $myboolean
    };

=cut

sub __serialize__Perm {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Perm';
    my $value    = shift || {};

    
    $value->{'permission'} = SOAP::Data->new (
        name => 'permission',
        type => 'xsd:boolean',
        value => $rawValue->{'permission'}
    );

    $value->{'remove'} = SOAP::Data->new (
        name => 'remove',
        type => 'xsd:boolean',
        value => $rawValue->{'remove'}
    );

    $value->{'read'} = SOAP::Data->new (
        name => 'read',
        type => 'xsd:boolean',
        value => $rawValue->{'read'}
    );

    $value->{'write'} = SOAP::Data->new (
        name => 'write',
        type => 'xsd:boolean',
        value => $rawValue->{'write'}
    );

    $value->{'list'} = SOAP::Data->new (
        name => 'list',
        type => 'xsd:boolean',
        value => $rawValue->{'list'}
    );

    $value->{'execute'} = SOAP::Data->new (
        name => 'execute',
        type => 'xsd:boolean',
        value => $rawValue->{'execute'}
    );

    $value->{'getMetadata'} = SOAP::Data->new (
        name => 'getMetadata',
        type => 'xsd:boolean',
        value => $rawValue->{'getMetadata'}
    );

    $value->{'setMetadata'} = SOAP::Data->new (
        name => 'setMetadata',
        type => 'xsd:boolean',
        value => $rawValue->{'setMetadata'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<BasicPermission>

    my $myBasicPermission = {
        userName => 'string', 
        groupName => 'string', 
        userPerm => $myPerm, 
        groupPerm => $myPerm, 
        otherPerm => $myPerm
    };

=cut

sub __serialize__BasicPermission {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'BasicPermission';
    my $value    = shift || {};

    
    $value->{'userName'} = SOAP::Data->new (
        name => 'userName',
        type => 'xsd:string',
        value => $rawValue->{'userName'}
    );

    $value->{'groupName'} = SOAP::Data->new (
        name => 'groupName',
        type => 'xsd:string',
        value => $rawValue->{'groupName'}
    );

    $value->{'userPerm'} = __serialize__Perm('userPerm', $rawValue->{'userPerm'});

    $value->{'groupPerm'} = __serialize__Perm('groupPerm', $rawValue->{'groupPerm'});

    $value->{'otherPerm'} = __serialize__Perm('otherPerm', $rawValue->{'otherPerm'});


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<ACLEntry>

    my $myACLEntry = {
        principalPerm => $myPerm, 
        principal => 'string'
    };

=cut

sub __serialize__ACLEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ACLEntry';
    my $value    = shift || {};

    
    $value->{'principalPerm'} = __serialize__Perm('principalPerm', $rawValue->{'principalPerm'});

    $value->{'principal'} = SOAP::Data->new (
        name => 'principal',
        type => 'xsd:string',
        value => $rawValue->{'principal'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<Permission>

    my $myPermission = new BasicPermission (
        
    );

=cut

sub __serialize__Permission {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Permission';
    my $value    = shift || {};

    
    $value->{'acl'} = SOAP::Data->new (
        name => 'acl',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'ACLEntry'},
        value => [ map { __serialize__ACLEntry(undef, $_); } @{$rawValue->{'acl'}} ]
    );


    # calling the superclass' serializer for the rest
    return __serialize__BasicPermission ($name, $rawValue, $type, $value);
}

=pod

=item B<SURLEntry>

    my $mySURLEntry = {
        masterReplica => $myboolean, 
        creationTime => $mylong, 
        modifyTime => $mylong, 
        surl => 'string'
    };

=cut

sub __serialize__SURLEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'SURLEntry';
    my $value    = shift || {};

    
    $value->{'masterReplica'} = SOAP::Data->new (
        name => 'masterReplica',
        type => 'xsd:boolean',
        value => $rawValue->{'masterReplica'}
    );

    $value->{'creationTime'} = SOAP::Data->new (
        name => 'creationTime',
        type => 'xsd:long',
        value => $rawValue->{'creationTime'}
    );

    $value->{'modifyTime'} = SOAP::Data->new (
        name => 'modifyTime',
        type => 'xsd:long',
        value => $rawValue->{'modifyTime'}
    );

    $value->{'surl'} = SOAP::Data->new (
        name => 'surl',
        type => 'xsd:string',
        value => $rawValue->{'surl'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<RCEntry>

    my $myRCEntry = {
        guid => 'string', 
        GUIDStat => $myGUIDStat, 
        permission => $myPermission, 
        surlStats => [ $mySURLEntry1, $mySURLEntry2, ... ]
    };

=cut

sub __serialize__RCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'RCEntry';
    my $value    = shift || {};

    
    $value->{'guid'} = SOAP::Data->new (
        name => 'guid',
        type => 'xsd:string',
        value => $rawValue->{'guid'}
    );

    $value->{'GUIDStat'} = __serialize__GUIDStat('GUIDStat', $rawValue->{'GUIDStat'});

    $value->{'permission'} = __serialize__Permission('permission', $rawValue->{'permission'});

    $value->{'surlStats'} = SOAP::Data->new (
        name => 'surlStats',
        type => 'SOAP-ENC:Array',
        attr => {arrayType => 'SURLEntry'},
        value => [ map { __serialize__SURLEntry(undef, $_); } @{$rawValue->{'surlStats'}} ]
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<LFNStat>

    my $myLFNStat = new Stat (
        
    );

=cut

sub __serialize__LFNStat {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'LFNStat';
    my $value    = shift || {};

    
    $value->{'type'} = SOAP::Data->new (
        name => 'type',
        type => 'xsd:int',
        value => $rawValue->{'type'}
    );

    $value->{'data'} = SOAP::Data->new (
        name => 'data',
        type => 'xsd:string',
        value => $rawValue->{'data'}
    );

    $value->{'validityTime'} = SOAP::Data->new (
        name => 'validityTime',
        type => 'xsd:long',
        value => $rawValue->{'validityTime'}
    );


    # calling the superclass' serializer for the rest
    return __serialize__Stat ($name, $rawValue, $type, $value);
}

=pod

=item B<FRCEntry>

    my $myFRCEntry = new RCEntry (
        
    );

=cut

sub __serialize__FRCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'FRCEntry';
    my $value    = shift || {};

    
    $value->{'lfn'} = SOAP::Data->new (
        name => 'lfn',
        type => 'xsd:string',
        value => $rawValue->{'lfn'}
    );

    $value->{'lfnStat'} = __serialize__LFNStat('lfnStat', $rawValue->{'lfnStat'});


    # calling the superclass' serializer for the rest
    return __serialize__RCEntry ($name, $rawValue, $type, $value);
}

=pod

=item B<ExistsException>

    my $myExistsException = new CatalogException (
        
    );

=cut

sub __serialize__ExistsException {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'ExistsException';
    my $value    = shift || {};

    

    # calling the superclass' serializer for the rest
    return __serialize__CatalogException ($name, $rawValue, $type, $value);
}

=pod

=item B<StringPair>

    my $myStringPair = {
        string1 => 'string', 
        string2 => 'string'
    };

=cut

sub __serialize__StringPair {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'StringPair';
    my $value    = shift || {};

    
    $value->{'string1'} = SOAP::Data->new (
        name => 'string1',
        type => 'xsd:string',
        value => $rawValue->{'string1'}
    );

    $value->{'string2'} = SOAP::Data->new (
        name => 'string2',
        type => 'xsd:string',
        value => $rawValue->{'string2'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<FCEntry>

    my $myFCEntry = {
        lfn => 'string', 
        guid => 'string', 
        permission => $myPermission, 
        lfnStat => $myLFNStat
    };

=cut

sub __serialize__FCEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'FCEntry';
    my $value    = shift || {};

    
    $value->{'lfn'} = SOAP::Data->new (
        name => 'lfn',
        type => 'xsd:string',
        value => $rawValue->{'lfn'}
    );

    $value->{'guid'} = SOAP::Data->new (
        name => 'guid',
        type => 'xsd:string',
        value => $rawValue->{'guid'}
    );

    $value->{'permission'} = __serialize__Permission('permission', $rawValue->{'permission'});

    $value->{'lfnStat'} = __serialize__LFNStat('lfnStat', $rawValue->{'lfnStat'});


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<PermissionEntry>

    my $myPermissionEntry = {
        item => 'string', 
        permission => $myPermission
    };

=cut

sub __serialize__PermissionEntry {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'PermissionEntry';
    my $value    = shift || {};

    
    $value->{'item'} = SOAP::Data->new (
        name => 'item',
        type => 'xsd:string',
        value => $rawValue->{'item'}
    );

    $value->{'permission'} = __serialize__Permission('permission', $rawValue->{'permission'});


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<Attribute>

    my $myAttribute = {
        name => 'string', 
        value => 'string', 
        type => 'string'
    };

=cut

sub __serialize__Attribute {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'Attribute';
    my $value    = shift || {};

    
    $value->{'name'} = SOAP::Data->new (
        name => 'name',
        type => 'xsd:string',
        value => $rawValue->{'name'}
    );

    $value->{'value'} = SOAP::Data->new (
        name => 'value',
        type => 'xsd:string',
        value => $rawValue->{'value'}
    );

    $value->{'type'} = SOAP::Data->new (
        name => 'type',
        type => 'xsd:string',
        value => $rawValue->{'type'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}

=pod

=item B<StringBoolean>

    my $myStringBoolean = {
        string => 'string', 
        bool => $myboolean
    };

=cut

sub __serialize__StringBoolean {
    my $name     = shift; # the name of the element
    my $rawValue = shift; # the Perl structure w/o type info

    # dealing with inheritance: optional parameters from the subclass
    # calling the superclass' serializer routine with its type and fields
    my $type     = shift || 'StringBoolean';
    my $value    = shift || {};

    
    $value->{'string'} = SOAP::Data->new (
        name => 'string',
        type => 'xsd:string',
        value => $rawValue->{'string'}
    );

    $value->{'bool'} = SOAP::Data->new (
        name => 'bool',
        type => 'xsd:boolean',
        value => $rawValue->{'bool'}
    );


    return SOAP::Data->new (name => $name, type => $type, value => $value);
}



=pod

=back

=head1 SEE ALSO

L<GLite::HTTPS>

=head1 AUTHORS

Copyright (c) 2004 CERN, on behalf of the EU EGEE project.
For license conditions see LICENSE file or
L<http://www.edg.org/license.html>.

=cut

1;
