#!/usr/bin/perl -w

use ExtUtils::testlib;
use Data::UUID;
use Data::Dumper;

BEGIN { print "1..3\n"; }

use GLite::Data::FAS;

die "Please set FILECAT_ENDPOINT!\n" unless exists($ENV{FILECAT_ENDPOINT});

sub addOneGuid {
    my $fas = shift;
    my $guid = shift;

    # read only permission bits
    my $permissionbits = {
        'read'          => 1,
        'write'         => 0,
        'remove'        => 0,
        'permission'    => 0,
        'list'          => 1,
        'execute'       => 0
    };

    my $p1 = {
        'item'       => $guid,
        'permission' => {
            'acl'       => [],
            'userName'  => 'egee',
            'groupName' => 'egee-group',
            'userPerm'  => $permissionbits,
            'groupPerm' => $permissionbits,
            'otherPerm' => $permissionbits
        }
    };

    $fas->addGUID([$p1]);
}

sub checkOneGuid {
    my $fas = shift;
    my $guid = shift;

    my $p1 = $fas->getGuidPermission([$guid]);
    local $Data::Dumper::Pad = "    PermissionEntry: ";
    print Dumper($p1);

    unless (defined ($p1) and ($p1->[0]->{'item'} eq $guid)) {
        die "Didn't return the expected entry!\n";
    }
}


my $fascat = GLite::Data::FAS->new($ENV{FILECAT_ENDPOINT});
unless (defined ($fascat)) { warn "The service is not initalized!\n"; print "not "; } print "ok 1\n";

print "testGetVersion\n";
eval { print "Server version: ", $fascat->getVersion(), "\n"; };
if ($@) { warn $@; print "not "; } print "ok 2\n";

print "testSetOneGuid\n";
eval {
    my $ug = new Data::UUID;
    my $guid = $ug->create_str();
    print "GUID is: $guid\n";

    addOneGuid ($fascat, $guid);
    checkOneGuid ($fascat, $guid);
};
if ($@) { warn $@; print "not "; } print "ok 3\n";

    

